\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ems-mag-author}[2022/07/27 EMS magazine class (author version)]

%%% Options
\RequirePackage{kvoptions}
\SetupKeyvalOptions{ family = emsmag, prefix = @emsmag@ }
\DeclareStringOption[english]{lang}
\DeclareBoolOption{draft}
\DeclareBoolOption{print}
\ProcessKeyvalOptions*

%%% \thepage may be required somewhere
\pagenumbering{arabic}
\pagestyle{empty}

%%% paper size
\paperwidth 210mm
\paperheight 250mm

\newdimen\@grid
\global\@grid 12.5\p@
% \directlua{ emsmag = require('emsmag.lua') }
% \directlua{ emsmag.enablenosingleletter(false) }

\topskip \@grid
\splittopskip \topskip
\def\@firstlineoffset{\dimexpr\@grid-\f@size\p@+\p@}
%%% TODO restore lineskip where needed
\lineskip \z@skip
\lineskiplimit -\maxdimen

\maxdepth .5\@grid

\bigskipamount \@grid
\medskipamount .5\@grid
\smallskipamount .25\@grid

\partopsep \@grid

%%% font size
\renewcommand*\normalsize{%
	\@setfontsize\normalsize\@ixpt\@grid
	\abovedisplayskip 6\p@
	\belowdisplayskip 6.5\p@
	\abovedisplayshortskip \abovedisplayskip
	\belowdisplayshortskip \belowdisplayshortskip
	\jot 4.5\p@
}
\normalsize
\DeclareRobustCommand\small{%
	\@setfontsize\small\@viiipt{11}%
	\abovedisplayskip 3.5\p@
	\belowdisplayskip 4.5\p@
	\abovedisplayshortskip \abovedisplayskip
	\belowdisplayshortskip \belowdisplayshortskip
	\jot 4\p@
}
\let\footnotesize\small
\DeclareRobustCommand\tiny{\@setfontsize\tiny\@vipt{7.5}}
\DeclareRobustCommand\scriptsize{\@setfontsize\scriptsize\@viipt{9.7}}
\DeclareRobustCommand\large{\@setfontsize\large{11.3}{15.2}}
\DeclareRobustCommand\Large{\@setfontsize\Large{14.3}{18.3}}
\DeclareRobustCommand\LARGE{\@setfontsize\LARGE{18}{22.1}}
\DeclareRobustCommand\huge{\@setfontsize\huge{22.6}{26.6}}
\DeclareRobustCommand\Huge{\@setfontsize\Huge{28.5}{32}}
\DeclareMathSizes\@viiipt\@viiipt{6.4}{5.1}
\DeclareMathSizes\@ixpt\@ixpt\@viipt\@vipt
\DeclareMathSizes{11.3}{11.3}\@ixpt\@viipt
\DeclareMathSizes{14.3}{14.3}{11.3}\@ixpt
\DeclareMathSizes{18}{18}{14.3}{11.3}
\DeclareMathSizes{22.6}{22.6}{18}{14.3}
\DeclareMathSizes{28.5}{28.5}{22.6}{18}

%%% language
\RequirePackage[
	american, british,
	main = \@emsmag@lang,
	shorthands = off
]{babel}
\lefthyphenmin \tw@
\righthyphenmin \thr@@
\renewcommand*\americanhyphenmins{23}
\renewcommand*\britishhyphenmins{23}
% \hyphenationmin 6

%%% fonts
\RequirePackage[utf8]{inputenc}
\renewcommand*\bfdefault{sb}
%\pdfmapfile{cm-super-t1.map}
%\pdfmapfile{hfbright.map}
\RequirePackage{cmbright}
\RequirePackage[T1]{fontenc}

%%% page layout
\RequirePackage{geometry}
\@twocolumntrue
\@twosidetrue
\geometry{
	includefoot = false,
	includehead = false,
	text={18cm,22.5cm},
	innermargin = 15mm,
	heightrounded,
	footskip = 10mm,
	columnsep = 8mm,
	marginparsep = 2mm,
	marginparwidth = 12mm
}
\parindent 5mm
\parskip \z@skip

%%% math
\RequirePackage[tbtags]{amsmath}
\RequirePackage{amssymb}

\thickmuskip 5mu \@plus\@ne mu \@minus\tw@ mu\relax
\medmuskip 4mu \@plus\@ne mu \@minus\@ne mu\relax
\thinmuskip \thr@@ mu \@plus\@ne mu \@minus\@ne mu\relax

% \RequirePackage{mleftright}
% 	\mleftright

%%% spacing in cases
\renewcommand*\env@cases{%
	\let\@ifnextchar\new@ifnextchar
	\left\lbrace
	\renewcommand*\arraystretch{1.2}%
	\normalbaselines
	\array{@{\,}l@{\quad}l@{}}%
}

%%% grid
\if@emsmag@draft
	\overfullrule 1em
	\AddToHook{shipout/background}{%
		\xdef\grid@m{\ifodd\c@page\oddsidemargin\else\evensidemargin\fi}%
		\def\grid@x{\dimexpr1in+\grid@m}%
		\def\grid@y{-\dimexpr1in+\topmargin+\headheight+\headsep+\topskip}%
		\put (\grid@x, \grid@y) {%
			\vtop to \dimexpr\textheight\relax{\color{red!20}%
				\hrule \@height.2\p@\relax
				\leaders\vbox to \@grid{%
					\hrule \@width\textwidth \@height.2\p@\relax
					\vfill
				}%
				\vss
			}%
		}%
	}
\fi
\newsavebox\@gridbox
\newenvironment{togrid}[1][]{%
	\setbox\@gridbox\color@vbox
		\normalbaselines
		\normalcolor #1%
}{%
	\color@endbox
% 	\directlua{ emsmag.gridbox('@gridbox') }%
	\box\@gridbox
}
\newsavebox\@eqgridbox
\newdimen\@grideqshift
\newcommand*\grideqshift[1]{\global\@grideqshift #1\p@}
\newenvironment{eqtogrid}{%
	\setbox\@eqgridbox\color@vbox
		\normalcolor
		\normalbaselines
}{%
	\color@endbox
% 	\directlua{ emsmag.grideq('@eqgridbox') }%
	\ifvmode\leavevmode\fi\unskip
	\vadjust{%
		\penalty\predisplaypenalty
		\vskip-\@grideqshift
		\hbox\bgroup\m@th$\everyvbox{%
			\everyvbox{}%
			\aftergroup$\aftergroup\egroup
		}%
		\vcenter to \ht\@eqgridbox{\vss\unvbox\@eqgridbox\vss}%
		\vskip\@grideqshift
	}\hfil\par\@doendpe
	\global\@grideqshift \z@
}

\RequirePackage{etoolbox}
\preto\equation{\eqtogrid}
\appto\endequation{\endeqtogrid}{}{}
\def\e@preto#1{\expandafter\preto\csname\string #1\endcsname}
\def\e@appto#1{\expandafter\appto\csname\string #1\endcsname}
\e@preto{equation*}{\eqtogrid}
\e@appto{endequation*}{\endeqtogrid}

\preto\align{\eqtogrid}
\preto\alignat{\eqtogrid}
\e@preto{align*}{\eqtogrid}
\e@preto{alignat*}{\eqtogrid}
\appto\endalign{\endeqtogrid}{}{}

\preto\gather{\eqtogrid}
\e@preto{gather*}{\eqtogrid}
\appto\endgather{\endeqtogrid}{}{}

\preto\multline{\eqtogrid}
\e@preto{multline*}{\eqtogrid}
\appto\endmultline{\endeqtogrid}{}{}

%%% float
% \RequirePackage{dblfloatfix}
\RequirePackage{stfloats}
\floatsep \@grid
\intextsep 2\@grid
\textfloatsep 2\@grid
\@fpbot \z@ \@plus1fil
\@fpsep 1.5\@grid
\@fptop \z@skip
\dblfloatsep \floatsep
\dbltextfloatsep \textfloatsep
\@dblfptop \@fptop
\@dblfpbot \@fpbot
\@dblfpsep \@fpsep
\renewcommand*\topfraction{.8}
\renewcommand*\bottomfraction{.8}
\renewcommand*\textfraction{.2}
\renewcommand*\floatpagefraction{.8}
\renewcommand*\dbltopfraction{.8}
\renewcommand*\dblfloatpagefraction{.8}
\appto\@floatboxreset\small{}{}
\newdimen\halfwidth
\newdimen\thirdwidth
\AtBeginDocument{%
	\halfwidth .5\dimexpr\linewidth-2ex\relax
	\thirdwidth .333\dimexpr\linewidth-4ex\relax
}
\newbox\ems@cfigbox
\newcommand*\centerfigure[1]{%
% 	\centering
	\setbox\ems@cfigbox\hbox{#1}%
	\captionsetup{width = \wd\ems@cfigbox}%
	\unhbox\ems@cfigbox
}
\newcounter{figure}
\def\fps@figure{!ht}
\def\ftype@figure{1}
\def\ext@figure{lof}
\newcommand*\figurename{Figure}
\newenvironment{figure}[1][\fps@figure]{%
	\edef\reserved@a{\noexpand\@float{figure}[#1]}\reserved@a
	\m@th\togrid[\vspace*{\@firstlineoffset}]%
}{\endtogrid\end@float}
\newenvironment{figure*}[1][\fps@figure]{%
	\edef\reserved@a{\noexpand\@dblfloat{figure}[#1]}\reserved@a
	\m@th\togrid[\vspace*{\@firstlineoffset}]\centering
}{\endtogrid\end@dblfloat}
\newenvironment{startwrapfigure}[1]
	{\noindent\begin{wrapfigure}{l}{#1}\vskip-\intextsep}
	{\vskip-\intextsep \vskip\baselineskip \end{wrapfigure}}
\newcounter{table}
\def\fps@table{!ht}
\def\ftype@table{2}
\def\ext@table{lot}
\newcommand*\tablename{Table}
\newenvironment{table}[1][\fps@table]{%
	\edef\reserved@a{\noexpand\@float{table}[#1]}\reserved@a
	\m@th\togrid[\vspace*{\@firstlineoffset}]%
}{\endtogrid\end@float}
\newenvironment{table*}[1][\fps@table]{%
	\edef\reserved@a{\noexpand\@dblfloat{table}[#1]}\reserved@a
	\m@th\togrid[\vspace*{\@firstlineoffset}]\centering
}{\endtogrid\end@dblfloat}
%%% side caption float
\newdimen\scsep
\scsep 3mm
\newsavebox\SC@floatbox
\let\SC@caption\@empty
\let\SC@@caption\@empty
\def\SC@float#1#2{%
	\xdef\SC@type{#1}%
	\xdef\SC@fps{#2}%
	\def\caption{\@ifstar\SC@caption\SC@@caption}%
	\renewcommand\SC@@caption[2][]{%
		\gdef\sc@saved@captoc{##1}%
		\gdef\sc@saved@cap{##2}%
	}%
	\renewcommand\SC@caption[2][]{%
		\global\let\sc@saved@capstar\relax
		\SC@@caption[##1]{##2}%
	}%
	\begin{lrbox}\SC@floatbox
		\@floatboxreset
}
\newdimen\SC@floatwd
\newdimen\SC@capwd
\newif\ifscswap \scswapfalse
\def\endSC@float{%
	\end{lrbox}%
	\edef\reserved@a{\noexpand\csname \SC@type\endcsname[\SC@fps]}%
	\reserved@a\ignorespaces
		\SC@floatwd \wd\SC@floatbox
		\SC@capwd \dimexpr\linewidth-\SC@floatwd-\scsep\relax
		\def\SC@cap{%
			\begin{minipage}[b]\SC@capwd
				\captionsetup{
					aboveskip = \z@,
					belowskip = \z@,
					position = bottom
				}%
				\ifscswap\captionsetup{justification = raggedleft}\fi
				\ifx\sc@saved@capstar\relax
					\captionsetup{labelformat = empty}%
					\global\let\sc@saved@capstar\@undefined
				\else
					\refstepcounter\@captype
				\fi
				\caption@@caption{\@captype}[\sc@saved@captoc]{\sc@saved@cap}%
				\global\let\sc@saved@captoc\@empty
				\global\let\sc@saved@cap\@empty
			\end{minipage}%
		}%
		\ifscswap\SC@cap\hskip\scsep\nobreak\fi
		\begin{minipage}[b]\SC@floatwd
			\hrule \@height\z@ \@depth\z@
			\unhbox\SC@floatbox
			%%% align baseline with caption?
			\@finalstrut\strutbox
			\hrule \@height\z@ \@depth\z@
		\end{minipage}%
		\ifscswap\else\hskip\scsep\nobreak\SC@cap\fi
		\global\scswapfalse
	\@nameuse{end\SC@type}%
}
\newenvironment{scfigure}[1][\fps@figure]
	{\SC@float{figure}{#1}}{\endSC@float}
\newenvironment{scfigure*}[1][\fps@figure]
	{\SC@float{figure*}{#1}}{\endSC@float}
\newenvironment{sctable}[1][\fps@table]
	{\SC@float{table}{#1}}{\endSC@float}
\newenvironment{sctable*}[1][\fps@table]
	{\SC@float{table*}{#1}}{\endSC@float}
\RequirePackage[figuresright]{rotating}
\def\@xrotfloat#1[#2]{%
	\@float{#1}[#2]%
	\begin{lrbox}\rot@float@box
	\begin{minipage}[t][][b]\textheight
}
\def\@rotxdblfloat#1[#2]{%
	\@float{#1}[#2]%
	\hsize\textwidth\linewidth\textwidth
	\begin{lrbox}\rot@float@box
	\begin{minipage}[t][][b]\textheight
}
\rotFPtop\z@

%%% footer
\newcounter{doi}
\newcommand*\doi[1]{\gdef\@doi{#1}}
\newcommand*\issue[1]{\gdef\@issue{#1}}
\newcommand*\emsmag@foot{\tiny EMS MAGAZINE \@issue\ (\the\year)}
\newcommand*\emsmag@doi{DOI 10.4171/MAG/\@doi}
\newcommand*\makedoi{\par
	\nopagebreak
% 	\returntogrid
	\hfill {\tiny\emsmag@doi}\@finalstrut\strutbox
}
\renewcommand*\ps@plain{%
	\let\@evenhead\@empty
	\let\@oddhead\@empty
	\def\@evenfoot{{\footnotesize\thepage}\hfill {\emsmag@foot}}%
	\def\@oddfoot{{\emsmag@foot}\hfill {\footnotesize\thepage}}%
}
\pagestyle{plain}
\newcommand*\ps@doipage{%
	\let\@evenhead\@empty
	\let\@oddhead\@empty
	\def\@evenfoot{{\footnotesize\thepage}\hfill {\emsmag@foot\ --- \emsmag@doi}}%
	\def\@oddfoot{{\emsmag@foot\ --- \emsmag@doi}\hfill {\footnotesize\thepage}}%
}

%%% multiple columns
\RequirePackage{multicol}
\multicolbaselineskip \z@skip
\premulticols \@grid
\postmulticols \@grid
\raggedcolumns

%%% footnote
\interfootnotelinepenalty \@M
\RequirePackage[bottom]{footmisc}
\renewcommand*\footnoterule{\kern-4\p@ \hrule\@width5mm \@height\p@ \kern3\p@}
\footnotesep \dp\strutbox
\renewcommand*\footnotelayout\RaggedRight
\renewcommand*\@makefnmark{\hbox{\normalfont\textsuperscript{\@thefnmark}}}
\renewcommand\@makefntext[1]{%
	\noindent\llap{\@makefnmark\,}\strut
	\lineskip\z@skip \lineskiplimit-\maxdimen
	\footnotelayout#1%
}
\skip\footins 2\@grid \@minus\@grid

%%% misc
\RequirePackage[final,protrusion=false,expansion=false]{microtype}
\RequirePackage{upref}
\RequirePackage{ragged2e}
% \RaggedRightRightskip \z@ \@plus4\@grid\relax
\RaggedRightRightskip \z@ \@plus8mm\relax
\patchcmd\RaggedRight
	{\@raggedtwoe@spaceskiptrue}
	{\@raggedtwoe@spaceskipfalse}
	{}{}
\gappto\RaggedRight{%
	\lefthyphenmin 3%
	\righthyphenmin 4%
	\hfuzz .5em%
	\hyphenpenalty 60\relax
}{}{}
\AtBeginDocument\frenchspacing
\raggedbottom
\widowpenalty \@M
\clubpenalty \@M
\doublehyphendemerits 100000000
\finalhyphendemerits 100000000

%%% caption
\RequirePackage{caption}
\captionsetup{
	font = footnotesize,
	format = plain,
	justification = raggedright,
	labelfont = it,
	labelsep = period,
	singlelinecheck = false
}
\captionsetup[table]{position = above, skip = 1ex}
\captionsetup[figure]{position = below, skip = 2ex}

%%% section
\setcounter{secnumdepth}{2}
\newcounter{section}[doi]
\newcounter{subsection}[section]
\newcounter{subsubsection}[subsection]
\newcounter{paragraph}[subsubsection]
\renewcommand*\thesection{\@arabic\c@section}
\renewcommand*\thesubsection{\thesection.\@arabic\c@subsection}
\renewcommand*\thesubsubsection{\thesubsection.\@arabic\c@subsubsection}
\renewcommand*\theparagraph{\thesubsubsection.\@arabic\c@paragraph}
\renewcommand*\@seccntformat[1]{\hb@xt@8mm{\csuse{the#1}\hss}}
\newcommand*\@runinformat[1]{#1\@addpunct{.}}
\RequirePackage{silence}
\WarningFilter{titlesec}{Non standard sectioning command}
\RequirePackage{titlesec}
\titleformat{\section}
	{\normalfont\bfseries\raggedright}
	{\@seccntformat{section}}{\z@}{}
\titlespacing*{\section}{\z@}{2\@grid}{\@grid}
\titleformat{\subsection}
      {\normalsize\itshape\bfseries\raggedright}
      {\@seccntformat{subsection}}{\z@}{}
\titlespacing*{\subsection}{\z@}{2\@grid}{\z@}
\titleformat{\subsubsection}
      {\normalsize\itshape\raggedright}
      {\@seccntformat{subsubsection}}{\z@}{}
\titlespacing*{\subsubsection}{\z@}{\@grid}{\z@}
\titleformat{\paragraph}[runin]
      {\normalsize\itshape}
      {\normalfont\theparagraph}{\z@}{\@runinformat}
\titlespacing*{\paragraph}{\z@}{\@grid}{.5em}

\providecommand*\description{}
\labelsep .5em
\RequirePackage[shortlabels]{enumitem}
\setlist{ nolistsep, font = \upshape }
\setlist[itemize]{ leftmargin = * }
\setlist[itemize, 1]{ label = \textbullet, leftmargin = \parindent }
\setlist[itemize, 2]{ label = \textendash }
\setlist[enumerate]{ leftmargin = * }
\setlist[enumerate, 1]{ label = \upshape\arabic*., leftmargin = \parindent }
\setlist[enumerate, 2]{ label = (\upshape\alph*), align = left }
\setlist[enumerate, 3]{ label = (\upshape\roman*), align = left }
\setlist[enumerate, 4]{ label = (\upshape\Alph*), align = left }
\setlist[description]{ font = \normalfont }
\newcommand*\emsblock{\rule{.7ex}{.7ex}}

\newenvironment{block}[1][1]{%
	\list{}{%
		\leftmargin \parindent
		\rightmargin \leftmargin
		\partopsep \z@
		\topsep #1\@grid
	}\item\relax
}{\endlist}
\newenvironment{quote}{%
	\list{}{%
		\leftmargin \parindent
		\partopsep \z@
		\topsep \@grid
	}%
	\item\RaggedRight
}{\endlist}
\newenvironment{verse}{%
	\let\\\@centercr
	\list{}{%
		\itemsep \z@
		\itemindent -\parindent
		\listparindent \itemindent
		\leftmargin 2\parindent
		\rightmargin \z@
	}\item\relax
}{\endlist}
\newcommand\attrib[1]{%
	\par\nopagebreak
	\setbox\@tempboxa\hbox{{\itshape #1}}%
	\ifdim\parindent <\dimexpr\linewidth-\wd\@tempboxa\relax
		\leavevmode\hfill \unhbox\@tempboxa
	\else
		\addvspace\@grid
		\begingroup
			\raggedright
			\leftskip 5mm\relax
			\unhbox\@tempboxa\par
		\endgroup
	\fi
	\par\vskip\@grid
}

\newenvironment{abstract}{%
	\list{}{%
		\leftmargin \z@
		\rightmargin \leftmargin
		\topsep \@grid
		\listparindent \parindent
	}%
	\item\itshape
}{\endlist\addvspace{2\@grid}\@afterindentfalse}

%%% references
\RequirePackage[noadjust]{cite}
\renewcommand*\citedash{–}
%%% cite always upright
\renewcommand*\@cite[2]{%
	\leavevmode \cite@adjust
	{\upshape
		\citeleft{%
			#1\if@tempswa\@safe@activesfalse\citemid{#2}\fi
			\spacefactor\@m
		}\citeright
	}\@restore@auxhandle
}
\newcommand*\refname{References}
\newenvironment{thebibliography}[1]{%
	\section*{\normalfont\itshape\refname}%
	\setlist{align = left}%
	\list{\@biblabel{\@arabic\c@enumiv}}{%
		\settowidth\labelwidth{\@biblabel{#1}}%
		\leftmargin \labelwidth
		\advance\leftmargin \labelsep
		\itemsep .5ex
		\usecounter{enumiv}%
		\let\p@enumiv\@empty
		\renewcommand*\theenumiv{\@arabic\c@enumiv}%
	}%
	\setcounter{enumiv}{0}%
	\footnotesize
	\RaggedRight\sloppy
	\interlinepenalty \@M
}{%
	\def\@noitemerr{\@latex@warning{Empty `thebibliography' environment}}%
	\endlist
}
\newcommand*\thesubbibliography{}
\let\thesubbibliography\thebibliography
\patchcmd\thesubbibliography{\section*{\normalfont\itshape\refname}}{%
	\titlespacing*{\subsection}{\z@}{\@grid}{.5ex}%
	\subsection*{\normalfont\itshape\refname}%
}{}{}
\let\endthesubbibliography\endthebibliography
% \appto\endthesubbibliography{\vskip-2\@grid \returntogrid}{}{}
\newcommand*\arXiv[1]{arXiv:\allowbreak\href{https://arxiv.org/abs/#1}{#1}}
\newcommand*\DOI[1]{DOI\,\href{https://dx.doi.org/#1}{#1}}%

\newcommand*\ackname{Acknowledgements}
\newenvironment{ack}[1][\ackname]{%
	\par \addvspace{2\@grid}%
	\noindent\textit{#1.}\enskip\ignorespaces
}{}

\newcommand*\emsmag@bar{\vrule \@width5mm \@depth.5\p@ \@height.5\p@}
\newenvironment{authorinfo}{%
	\small \RaggedRight \sloppy
	\par \addvspace{2\@grid \@minus\@grid}%
	\emsmag@bar \par\nobreak
	\let\em@il\email
	\def\email##1{\par\nobreak\vskip-.75\baselineskip \em@il{##1}}%
	\parskip \baselineskip
}{\par}

%%% graphics
\RequirePackage{graphicx}
%%% EMS colors
\if@emsmag@print
	\RequirePackage[cmyk]{xcolor}
	\definecolorset{cmyk}{}{}{%
		red, 0, 0.8, 0.8, 0.2;%
		green, 0.5, 0, 0.9, 0.3;%
		blue, 1, 0.2, 0, 0.4;%
		yellow, 0, 0.1, 0.9, 0.3%
	}
\else
	\RequirePackage[rgb]{xcolor}
	\definecolorset{HTML}{}{}{%
		red, CC2929;%
		green, 59B312;% RGB triadic
		blue, 007A99;%
		yellow, B3A112% RYB triadic
	}
\fi
\RequirePackage{subcaption}
	\captionsetup[sub]{labelfont =, font = footnotesize}
\RequirePackage{pdfpages}
\RequirePackage{wrapfig}
	\patchcmd\WF@putfigmaybe\columnsep{5mm}{}{}
	\patchcmd\WF@putfigmaybe\columnsep{5mm}{}{}
	\patchcmd\WF@putfigmaybe\columnsep{5mm}{}{}
\AtBeginDocument{%
	\@ifpackageloaded{tikz-cd}{%
		\tikzset{ > = stealth }%
		\tikzcdset{ arrow style = tikz }%
		\tikzcdset{ every arrow/.append style = {line width = .054em} }%
	}{}%
}
% \RequirePackage{makeidx}
% \makeindex
\newcommand{\license}[2][]{%
	\ifnum\pdf@strcmp{#2}{restricted-access}=0 %
		\protect\index{restricted-access}%
	\fi
}

%%% table
\tabcolsep 3\fontdimen2\font
\arraycolsep 2\fontdimen2\font
\arrayrulewidth .4\p@
\doublerulesep 2\p@
\fboxsep 3\p@
\fboxrule \arrayrulewidth
\newcommand*\Boxed[1]{{%
	\fboxsep \z@
	\fboxrule .3bp
	\fbox{#1}%
}}
\RequirePackage{tabularx}
\RequirePackage{booktabs}
\RequirePackage{multirow}
\RequirePackage{colortbl}
\definecolor{tablehead}{cmyk}{.2,0,0,0}
% TODO really printable?
\definecolor{tablebody}{cmyk}{.05,0,0,0}

%%% theorem
\RequirePackage{amsthm}
\newtheoremstyle{plain}{\@grid}{\@grid}{\itshape}{}{\bfseries}{.}{.5em}{}
\newtheoremstyle{definition}{\@grid}{\@grid}{\normalfont}{}{\bfseries}{.}{.5em}{}
%%% proof
\renewenvironment{proof}[1][\proofname]{\par
	\pushQED{\qed}%
	\normalfont
	\topsep \@grid
	\partopsep \z@
	\trivlist
		\item[%
			\hskip\labelsep\relax
			\itshape #1\@addpunct{.}%
		]\ignorespaces
}{\popQED\endtrivlist\@endpefalse}
%%% qed symbol
\newbox\ems@qedbox
\AtBeginDocument{%
	\setbox\@tempboxa\hbox{x}%
	\setbox\ems@qedbox\hbox{%
		\vrule\@width\ht\@tempboxa \@height\ht\@tempboxa \@depth\z@
	}%
}
\renewcommand*\qedsymbol{\relax
	\ifmmode\copy\ems@qedbox\else\unhcopy\ems@qedbox\fi
}

%%% table of contents
\newcommand*\tableofcontents{%
	\onecolumn
	\begingroup
		\thispagestyle{empty}
		\setcounter{tocdepth}{0}
		{\Large\hfill \smash{EMS Magazine \@issue}\par}
		\vskip 1.5\@grid
		\list{}{%
			\topsep \z@
			\leftmargin 30mm\relax
			\labelsep 10mm\relax
			\labelwidth 20mm\relax
			\rightmargin \z@
			\itemsep .5\@grid
		}%
		\item\raggedright
		\@starttoc{toc}
		\endlist
	\endgroup
	\twocolumn
}
\let\l@section\@gobbletwo
\let\l@subsection\@gobbletwo
\let\l@subsubsection\@gobbletwo
\let\l@paragraph\@gobbletwo

%%% title
\newcommand*\emsmag@reset{%
	\setcounter{section}{0}%
	\setcounter{footnote}{0}%
	\setcounter{table}{0}%
	\setcounter{figure}{0}%
	\setcounter{equation}{0}%
	\setcounter{footnote}{0}%
	\global\let\@author\@empty
	\global\let\@title\@empty
}
\newdimen\titleheight
\newcommand*\maketitle[1][12]{\par
	\titleheight #1\@grid
	\if@twocolumn
		\twocolumn[\@maketitle]%
	\else
		\global\@topnum \z@
		\@maketitle
	\fi
	\emsmag@reset
}
\newcommand*\subtitle[1]{\gdef\@subtitle{#1}}
\newcommand*\tocauthor[1]{\gdef\@tocauthor{#1}}
\newcommand*\toctitle[1]{\gdef\@toctitle{#1}}
\def\@maketitle{%
	\vbox to \titleheight{%
		\thispagestyle{doipage}%
		\raggedright
		\togrid
			\vrule \@width\z@ \@height2\@grid
			{\Large\bfseries\@title\par}%
			\ifx\@subtitle\@undefined\else\@subtitle\par\fi
		\endtogrid\par
		\vskip \@grid
		\vrule \@width\z@ \@height\@grid
		\ifx\@author\@empty\else
			\@author\par
			\vrule \@width\z@ \@height\@grid
		\fi
		\addtocontents{toc}{%
			\protect\item[\protect\hyperpage{\thepage}]
			\ifx\@toctitle\@undefined
				\@title
				\ifx\@subtitle\@undefined\else
					\par\nobreak\@subtitle
				\fi
			\else
				\@toctitle
			\fi
			\ifx\@tocauthor\@undefined
				\ifx\@author\@empty\else
					\par\nobreak \textit{\@author}%
				\fi
			\else
				\par\nobreak \textit{\@tocauthor}%
			\fi
		}%
		\global\let\@subtitle\@undefined
		\global\let\@tocauthor\@undefined
		\global\let\@toctitle\@undefined
		\vfill
	}%
}

%%% imprint (front/back)
\newcommand*\heading[1]{\par\addvspace{.5\baselineskip}\textit{#1}\par\nobreak}
\newenvironment{imprint}{%
	\onecolumn
	\fontsize{8pt}{10pt}\selectfont
	\raggedright
	\parskip .5\baselineskip
	\smallskipamount \parskip
	\bigskipamount \baselineskip
	\setlist[itemize, 1]{ label = \emsblock }%
}{\removelastskip \twocolumn}

%%% message
\newcommand*\@makemessagetitle{\par
	\begingroup
		\raggedright
		\togrid
			\vrule \@width\z@ \@height2\@grid \@depth\z@
			\large\fontseries{l}\selectfont\@title\par
		\endtogrid
		\vskip\@grid
	\endgroup
}
\newcommand*\@@makemessagetitle{%
	\@makemessagetitle
	\addtocontents{toc}{%
		\protect\item[\protect\hyperpage{\thepage}] \@title
		\ifx\@author\@empty\else\par\nobreak \textit{\@author}\fi
	}%
}
\newcommand*\makemessagetitle{\@ifstar\@makemessagetitle\@@makemessagetitle}

%%% review
\newcommand*\booktitle[1]{\gdef\@booktitle{#1}}
\newcommand*\bookauthor[1]{\gdef\@bookauthor{#1}}
\newcommand*\bookinfo[1]{\gdef\@bookinfo{#1}}
\newcommand*\reviewer[1]{\gdef\@reviewer{#1}}
\newcommand*\makereviewtitle{\par
	\goodbreak \vskip3\@grid
	\begingroup
		\raggedright
		\ifx\@booktitle\@undefined\else
			\textbf{\textit{\@booktitle}}%
			\ifx\@bookauthor\@undefined\else
				\space by~\@bookauthor
			\fi\par\nobreak
			\vskip\@grid
			\ifx\@reviewer\@undefined\else
				Reviewed by \@reviewer\par\nobreak
				\vskip\@grid
			\fi
		\fi
	\endgroup
}
\newcommand*\makereviewinfo{\par
	\addvspace{2\@grid \@minus\@grid}%
	\begingroup
		\small \raggedright \strut
		\ifx\@bookauthor\@undefined\else\@bookauthor,\space\fi
		\ifx\@booktitle\@undefined\else\textit{\@booktitle.}\space\fi
		\ifx\@bookinfo\@undefined\else\@bookinfo.\fi
		\par
	\endgroup
	\global\let\@bookauthor\@undefined
	\global\let\@booktitle\@undefined
	\global\let\@bookinfo\@undefined
}

%%% advertisement
\newcommand*\bradinfo{\vbox to \z@{\vskip3.3\p@\llap{\tiny ADVERTISEMENT}\vss}}
\newcommand*\bladinfo{\vbox to \z@{\vskip3.3\p@\rlap{\tiny ADVERTISEMENT}\vss}}

%%% hyperref and links
\RequirePackage[hyphens]{url}
\urlstyle{same}
%%% do not break http:// at colon
\patchcmd\UrlBreaks{\do\/}{}{}{}
\gappto\UrlBigBreaks{\do\/}{}{}
%%% otherwise, colon is U+2236
\gappto\UrlSpecials{\do\:{\text{:}}}{}{}
\RequirePackage[pdfa, hypertexnames = false]{hyperref}
\hypersetup{ pdfencoding = auto, psdextra }
\if@emsmag@print
	\hypersetup{ draft, pdftrapped = false }
\else
	\hypersetup{ allcolors = , colorlinks }
\fi
\newcommand*\email[1]{\href{mailto:#1}{\mbox{#1}}}

% \RequirePackage{returntogrid}
% \RequirePackage{preview}
% \RequirePackage{latexml}

\endinput
